@@ -45,7 +45,7 @@ static GooCanvasGroup	*stars_group		= NULL;
 static double           stars_group_x;
 static double           stars_group_y;
 
-#define Y_GAP	45
+#define Y_GAP	38
 
 static gboolean is_displayed			= FALSE;
 static gint x_flag_start;
@@ -66,6 +66,7 @@ static gchar *linguas[] = {
   "bg_BG.UTF-8",	N_("Bulgarian"),
   "ca_ES.UTF-8",	N_("Catalan"),
   "zh_CN.UTF-8",	N_("Chinese (Simplified)"),
+  "zh_HK.UTF-8",	N_("Chinese (Hong Kong)"),
   "zh_TW.UTF-8",	N_("Chinese (Traditional)"),
   "hr_HR.UTF-8",	N_("Croatian"),
   "cs_CZ.UTF-8",	N_("Czech Republic"),
@@ -77,9 +78,11 @@ static gchar *linguas[] = {
   "en_US.UTF-8",	N_("English (United States)"),
   "fi_FI.UTF-8",	N_("Finnish"),
   "fr_FR.UTF-8",	N_("French"),
+  "gl_ES.UTF-8",	N_("Galician"),
   "ka_GE.UTF-8",	N_("Georgian"),
   "de_DE.UTF-8",	N_("German"),
   "el_GR.UTF-8",	N_("Greek"),
+  "gd_GB.UTF-8",	N_("Scottish Gaelic"),
   "gu_IN.UTF-8",	N_("Gujarati"),
   "he_IL.UTF-8",	N_("Hebrew"),
   "hi_IN.UTF-8",	N_("Hindi"),
@@ -108,6 +111,7 @@ static gchar *linguas[] = {
   "pa_IN.UTF-8",	N_("Punjabi"),
   "ro_RO.UTF-8",	N_("Romanian"),
   "ru_RU.UTF-8",	N_("Russian"),
+  "gd_GB.UTF-8",	N_("Scottish Gaelic"),
   "sr@latin_RS.UTF-8",	N_("Serbian (Latin)"),
   "sr_RS.UTF-8",	N_("Serbian"),
   "sk_SK.UTF-8",	N_("Slovak"),
@@ -230,11 +234,11 @@ gc_config_start ()
 			     "svg-id", "#REPEAT",
 			     NULL);
     goo_canvas_item_get_bounds(item, &bounds);
-    double zoom = 0.65;
+    double zoom = 0.50;
     goo_canvas_item_scale(item, zoom, zoom);
     goo_canvas_item_translate(item,
-			      (-1 * bounds.x1 + x_flag_start - 340) * zoom,
-			      (-1 * bounds.y1 + y_start - 120) * zoom);
+			      (-1 * bounds.x1 + x_flag_start - 380) * zoom,
+			      (-1 * bounds.y1 + y_start - 145) * zoom);
   g_signal_connect(item, "button_press_event",
 		   (GCallback) item_event_ok,
 		   "locale_reset");
@@ -252,7 +256,7 @@ gc_config_start ()
 					  (gdouble) y_start,
 					  -1,
 					  GTK_ANCHOR_WEST,
-					  "font", gc_skin_font_subtitle,
+					  "font", gc_skin_font_content,
 					  "fill-color-rgba", gc_skin_color_content,
 					  NULL);
 
@@ -277,10 +281,36 @@ gc_config_start ()
 		       (gdouble) y_start,
 		       -1,
 		       GTK_ANCHOR_WEST,
-		       "font", gc_skin_font_subtitle,
+		       "font", gc_skin_font_content,
 		       "fill-color-rgba", gc_skin_color_content,
 		       NULL);
 
+  // Rememberlevel
+  y_start += Y_GAP;
+
+  item = goo_canvas_svg_new (rootitem,
+			     gc_skin_rsvg_get(),
+			     "svg-id", (properties->rememberlevel ? pixmap_checked : pixmap_unchecked),
+			     NULL);
+  SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
+
+  g_signal_connect(item, "button_press_event",
+		   (GCallback) item_event_ok,
+		   "rememberlevel");
+  gc_item_focus_init(item, NULL);
+
+
+  goo_canvas_text_new (rootitem,
+		       _("Remember level for default user"),
+		       (gdouble) x_text_start,
+		       (gdouble) y_start,
+		       -1,
+		       GTK_ANCHOR_WEST,
+		       "font", gc_skin_font_content,
+		       "fill-color-rgba", gc_skin_color_content,
+		       NULL);
+
+
   // Music
   y_start += Y_GAP;
 
@@ -302,7 +332,7 @@ gc_config_start ()
 		       (gdouble) y_start,
 		       -1,
 		       GTK_ANCHOR_WEST,
-		       "font", gc_skin_font_subtitle,
+		       "font", gc_skin_font_content,
 		       "fill-color-rgba", gc_skin_color_content,
 		       NULL);
 
@@ -327,7 +357,7 @@ gc_config_start ()
 		       (gdouble) y_start,
 		       -1,
 		       GTK_ANCHOR_WEST,
-		       "font", gc_skin_font_subtitle,
+		       "font", gc_skin_font_content,
 		       "fill-color-rgba", gc_skin_color_content,
 		       NULL);
 
@@ -351,7 +381,7 @@ gc_config_start ()
 		       (gdouble) y_start,
 		       -1,
 		       GTK_ANCHOR_WEST,
-		       "font", gc_skin_font_subtitle,
+		       "font", gc_skin_font_content,
 		       "fill-color-rgba", gc_skin_color_content,
 		       NULL);
 
@@ -366,7 +396,7 @@ gc_config_start ()
 					 (gdouble) y_start,
 					 -1,
 					 GTK_ANCHOR_WEST,
-					 "font", gc_skin_font_subtitle,
+					 "font", gc_skin_font_content,
 					 "fill-color-rgba", gc_skin_color_content,
 					 NULL);
 
@@ -425,7 +455,7 @@ gc_config_start ()
 					  (gdouble) y_start,
 					  -1,
 					  GTK_ANCHOR_WEST,
-					  "font", gc_skin_font_subtitle,
+					  "font", gc_skin_font_content,
 					  "fill-color-rgba", gc_skin_color_content,
 					  NULL);
     g_free(first_skin_name);
@@ -446,7 +476,7 @@ gc_config_start ()
 					  400,
 					  GTK_ANCHOR_WEST,
 					  "use-markup", TRUE,
-					  "font", gc_skin_font_subtitle,
+					  "font", gc_skin_font_content,
 					  "fill-color-rgba", gc_skin_color_content,
 					  NULL);
   g_free(text);
@@ -510,6 +540,18 @@ gc_locale_get_name(const gchar *locale_code)
    */
   const gchar *dot_char = g_strrstr ( locale, ".");
 
+  while(linguas[i] != NULL)
+    {
+
+      if( !g_ascii_strncasecmp(locale, linguas[i],
+			       (dot_char ? dot_char - locale : strlen(locale)) ) )
+	return(gettext(linguas[i+1]));
+
+      i=i+2;
+    }
+
+  dot_char = g_strrstr ( locale, "_");
+  i = 0;
   while(linguas[i] != NULL)
     {
 
@@ -776,6 +818,14 @@ item_event_ok(GooCanvasItem *item,
 	}
       gc_prop_save(properties);
     }
+  else if(!strcmp((char *)data, "rememberlevel"))
+    {
+      properties->rememberlevel = (properties->rememberlevel ? 0 : 1);
+      g_object_set(item,
+                   "svg-id", (properties->rememberlevel ? pixmap_checked : pixmap_unchecked),
+                   NULL);
+      gc_item_focus_init(item, NULL);
+    }
   else if(!strcmp((char *)data, "fullscreen"))
     {
       properties->fullscreen = (properties->fullscreen ? 0 : 1);
