@@ -1,6 +1,6 @@
 /* gcompris - gcompris.c
  *
- * Copyright (C) 2000, 2012 Bruno Coudoin
+ * Copyright (C) 2000, 2013 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -115,6 +115,7 @@ static gboolean		gc_debug = FALSE;
 /*** gcompris-popttable */
 static gint popt_fullscreen	   = FALSE;
 static gint popt_window		   = FALSE;
+static gint popt_rememberlevel     = FALSE;
 static gint popt_sound		   = FALSE;
 static gint popt_mute		   = FALSE;
 static gint popt_cursor		   = FALSE;
@@ -171,11 +172,8 @@ static GOptionEntry options[] = {
   {"difficulty", 'd', 0, G_OPTION_ARG_INT, &popt_difficulty_filter,
    N_("display only activities with this difficulty level."), NULL},
 
-  {"debug", 'D', 0, G_OPTION_ARG_NONE, &popt_debug,
-   N_("display debug informations on the console."), NULL},
-
-  {"version", 'v', 0, G_OPTION_ARG_NONE, &popt_version,
-   N_("Print the version of " PACKAGE), NULL},
+  {"rememberlevel", 'r', 0, G_OPTION_ARG_NONE, &popt_rememberlevel,
+   N_("Return to last passed level even when no user is selected"), NULL},
 
   {"root-menu", 'l', 0, G_OPTION_ARG_STRING, &popt_root_menu,
    N_("Run GCompris with local menu"
@@ -257,6 +255,12 @@ static GOptionEntry options[] = {
   {"test",'\0', 0, G_OPTION_ARG_NONE, &popt_test,
    N_("For test purpose, run in a loop all the activities"), NULL},
 
+  {"debug", 'D', 0, G_OPTION_ARG_NONE, &popt_debug,
+   N_("display debug informations on the console."), NULL},
+
+  {"version", 'v', 0, G_OPTION_ARG_NONE, &popt_version,
+   N_("Print the version of " PACKAGE), NULL},
+
   { NULL }
 };
 
@@ -373,11 +377,6 @@ board_widget_key_press_callback (GtkWidget   *widget,
       if (gc_board_get_current()->previous_board != NULL)
 	gc_board_stop();
       return TRUE;
-    case GDK_F5:
-      g_message("Refreshing the canvas\n");
-      goo_canvas_update(GOO_CANVAS(canvas));
-      return TRUE;
-
     case GDK_KP_Multiply:
       break;
     case GDK_KP_0:
@@ -1063,6 +1062,7 @@ activation_done()
     }
 
   gc_board_play( get_board_to_start());
+  gtk_widget_grab_focus(GTK_WIDGET(canvas));
   goo_canvas_item_remove (activation_item);
 }
 #endif
@@ -1710,6 +1710,11 @@ main (int argc, char *argv[])
       properties->fullscreen = FALSE;
     }
 
+  if(popt_rememberlevel)
+    {
+      properties->rememberlevel = TRUE;
+    }
+
   if (popt_mute)
     {
       g_message("Sound disabled");
