@@ -251,23 +251,31 @@ gint gc_timing (gint timeout, gint actors_number);
 #define COLOR_SUBTITLE		0xB00400FF
 #define COLOR_SHADOW		0x000000FF
 
+#define FONT_FONTFACE		"sans"
 #define FONT_TITLE		"sans 20"
 #define FONT_TITLE_FALLBACK	"sans 12"
 #define FONT_SUBTITLE		"sans 16"
 #define FONT_SUBTITLE_FALLBACK	"sans 12"
 #define FONT_CONTENT		"sans 12"
 #define FONT_CONTENT_FALLBACK	"sans 12"
+#define FONT_HELPTEXT           "sans 10"
 
-#define FONT_BOARD_TINY		"sans 10"
-#define FONT_BOARD_SMALL	"sans 12"
-#define FONT_BOARD_MEDIUM	"sans 14"
-#define FONT_BOARD_BIG		"sans 16"
-#define FONT_BOARD_BIG_BOLD	"sans bold 16"
-#define FONT_BOARD_FIXED	"fixed 12"
-#define FONT_BOARD_TITLE	"sans 20"
-#define FONT_BOARD_TITLE_BOLD	"sans bold 20"
-#define FONT_BOARD_HUGE		"sans 28"
-#define FONT_BOARD_HUGE_BOLD	"sans bold 28"
+#define FONT_MENU_TITLE         "sans 16"
+#define FONT_MENU_DESCRIPTION   "sans 10"
+
+#define FONT_BOARD_MINUSCULE    "sans 6"
+#define FONT_BOARD_TINY         "sans 10"
+#define FONT_BOARD_SMALL        "sans 12"
+#define FONT_BOARD_MEDIUM       "sans 14"
+#define FONT_BOARD_MEDIUM_BOLD  "sans bold 14"
+#define FONT_BOARD_BIG          "sans 16"
+#define FONT_BOARD_BIG_BOLD     "sans bold 16"
+#define FONT_BOARD_FIXED        "fixed 12"
+#define FONT_BOARD_TITLE        "sans 20"
+#define FONT_BOARD_TITLE_BOLD   "sans bold 20"
+#define FONT_BOARD_LEVELMENU	"sans bold 28"
+#define FONT_BOARD_HUGE         "sans 28"
+#define FONT_BOARD_HUGE_BOLD    "sans bold 28"
 
 /*=========================================================*/
 // These are gcompris defined cursors
