@@ -287,6 +287,7 @@ class Staff():
               x=self.endx - 100 + self.x,
               y=self.numStaves * self.verticalDistanceBetweenStaves + self.y,
               width=200,
+              font = gcompris.skin.get_font("gcompris/board/small"),
               text=_("The staff is full. Please erase some notes"),
               fill_color="black",
               anchor=gtk.ANCHOR_CENTER,
@@ -315,7 +316,8 @@ class Staff():
                 parent=self.rootitem,
                 x=x, #x + self.x,
                 y=self.y - 13, #y - 75 ,
-                text='<span size="' + size + '" >' + n + '</span>',
+                text = n,
+                font = gcompris.skin.get_font("gcompris/fontface") + " " + size,
                 fill_color="black",
                 anchor=gtk.ANCHOR_CENTER,
                 alignment=pango.ALIGN_CENTER,
@@ -389,6 +391,7 @@ class Staff():
                   x=note.x,
                   y=self.y + self.staffLineSpacing * 6 + 3,
                   text=text,
+                  font = gcompris.skin.get_font("gcompris/board/small"),
                   fill_color='black',
                   anchor=gtk.ANCHOR_CENTER,
                   alignment=pango.ALIGN_CENTER
@@ -1364,6 +1367,7 @@ class TextButton:
             x=x, y=y,
             width=width,
             text=text,
+            font = gcompris.skin.get_font("gcompris/board/small"),
             fill_color="white", anchor=gtk.ANCHOR_CENTER,
             alignment=pango.ALIGN_CENTER,
             pointer_events="GOO_CANVAS_EVENTS_NONE"
@@ -1428,6 +1432,7 @@ def textBox(text, x, y , rootitem, width=10000,
         y=y,
         width=width,
         text=text,
+        font = gcompris.skin.get_font("gcompris/board/small"),
         fill_color=text_color,
         anchor=gtk.ANCHOR_CENTER,
         alignment=pango.ALIGN_CENTER,
